Chapter 3: Search Chaining
==========================

In chapter 3, we introduce non-linear search chaining, whereby model-fits are chained together to enable efficient and
robust modeling of large strong lens samples.

The chapter contains the following tutorials:

`Tutorial 1: Search Chaining <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_1_search_chaining.ipynb>`_
- Breaking the lens modeling procedure into a chained sequence of model-fits.

`Tutorial 2: Prior Passing <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_2_prior_passing.ipynb>`_
- How the results of earlier searches are passed to later searches.

`Tutorial 3: Lens and Source <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_3_lens_and_source.ipynb>`_
- Fitting the lens's light followed by its mass using chained searches.

`Tutorial 4: Two Lens galaxies <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_4_x2_lens_galaxies.ipynb>`_
- Modeling a strong lens with two lens galaxies using chained searches.

`Tutorial 5: Complex Source <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_4_complex_source.ipynb>`_
- Using multiple light profiles to fit a complex and irregular source using chained searches.

`Tutorial 6: SLaM <https://mybinder.org/v2/gh/Jammy2211/autolens_workspace/release?filepath=notebooks/howtolens/chapter_3_search_chaining/tutorial_6_slam.ipynb>`_
- Template pipelines for fitting lens model is standardized ways.